@@ -15,7 +15,7 @@ from fastGAT.model import GAT,FastGAT
 
 
 class exe(): 
-    def __init__(self,save_model=True,datasetpath='./data/cora',no_cuda=False,bucket=4,fastmode=False,seed=3933,epochs=200,lr=0.005,weight_delay=5e-4,hidden=8,nb_heads=8,dropout=0.6,alpha=0.2,patience=100,fastGAT=1):
+    def __init__(self,save_model=True,datasetpath='fastGAT/data/cora/cora/',no_cuda=False,bucket=4,fastmode=False,seed=3933,epochs=200,lr=0.005,weight_delay=5e-4,hidden=8,nb_heads=8,dropout=0.6,alpha=0.2,patience=100,fastGAT=1):
 
 
         self.fastmode=fastmode
