@@ -1,7 +1,7 @@
 import torch
 import torch.nn as nn
 import torch.nn.functional as F
-from  fastGAT/layer import GraphAttentionLayer,LSHAttentionLayer
+from  fastGAT.layer import GraphAttentionLayer,LSHAttentionLayer
 
 
 class GAT(nn.Module):
